@@ -1,5 +1,5 @@
 #
-# Pyserini: Python interface to the Anserini IR toolkit built on Lucene
+# Pyserini: Reproducible IR research with sparse and dense representations
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -23,11 +23,24 @@ JAnalyzer = autoclass('org.apache.lucene.analysis.Analyzer')
 JArabicAnalyzer = autoclass('org.apache.lucene.analysis.ar.ArabicAnalyzer')
 JBengaliAnalyzer = autoclass('org.apache.lucene.analysis.bn.BengaliAnalyzer')
 JCJKAnalyzer = autoclass('org.apache.lucene.analysis.cjk.CJKAnalyzer')
-JGermanAnalyzer = autoclass('org.apache.lucene.analysis.de.GermanAnalyzer')
-JSpanishAnalyzer = autoclass('org.apache.lucene.analysis.es.SpanishAnalyzer')
-JFrenchAnalyzer = autoclass('org.apache.lucene.analysis.fr.FrenchAnalyzer')
-JHindiAnalyzer = autoclass('org.apache.lucene.analysis.hi.HindiAnalyzer')
+JDanishAnalyzer = autoclass('org.apache.lucene.analysis.da.DanishAnalyzer')
 JDefaultEnglishAnalyzer = autoclass('io.anserini.analysis.DefaultEnglishAnalyzer')
+JDutchAnalyzer = autoclass('org.apache.lucene.analysis.nl.DutchAnalyzer')
+JFinnishAnalyzer = autoclass('org.apache.lucene.analysis.fi.FinnishAnalyzer')
+JFrenchAnalyzer = autoclass('org.apache.lucene.analysis.fr.FrenchAnalyzer')
+JGermanAnalyzer = autoclass('org.apache.lucene.analysis.de.GermanAnalyzer')
+JHindiAnalyzer = autoclass('org.apache.lucene.analysis.hi.HindiAnalyzer')
+JHungarianAnalyzer = autoclass('org.apache.lucene.analysis.hu.HungarianAnalyzer')
+JIndonesianAnalyzer = autoclass('org.apache.lucene.analysis.id.IndonesianAnalyzer')
+JItalianAnalyzer = autoclass('org.apache.lucene.analysis.it.ItalianAnalyzer')
+JJapaneseAnalyzer = autoclass('org.apache.lucene.analysis.ja.JapaneseAnalyzer')
+JNorwegianAnalyzer = autoclass('org.apache.lucene.analysis.no.NorwegianAnalyzer')
+JPortugueseAnalyzer = autoclass('org.apache.lucene.analysis.pt.PortugueseAnalyzer')
+JRussianAnalyzer = autoclass('org.apache.lucene.analysis.ru.RussianAnalyzer')
+JSpanishAnalyzer = autoclass('org.apache.lucene.analysis.es.SpanishAnalyzer')
+JSwedishAnalyzer = autoclass('org.apache.lucene.analysis.sv.SwedishAnalyzer')
+JThaiAnalyzer = autoclass('org.apache.lucene.analysis.th.ThaiAnalyzer')
+JTurkishAnalyzer = autoclass('org.apache.lucene.analysis.tr.TurkishAnalyzer')
 JWhiteSpaceAnalyzer = autoclass('org.apache.lucene.analysis.core.WhitespaceAnalyzer')
 JCharArraySet = autoclass('org.apache.lucene.analysis.CharArraySet')
 
@@ -37,12 +50,12 @@ JDefaultEnglishAnalyzer = autoclass('io.anserini.analysis.DefaultEnglishAnalyzer
 JTweetAnalyzer = autoclass('io.anserini.analysis.TweetAnalyzer')
 
 
-def get_lucene_analyzer(name='english', stemming=True, stemmer='porter', stopwords=True) -> JAnalyzer:
+def get_lucene_analyzer(language='en', stemming=True, stemmer='porter', stopwords=True) -> JAnalyzer:
     """Create a Lucene ``Analyzer`` with specific settings.
 
     Parameters
     ----------
-    name : str
+    language : str
         Name of analyzer.
     stemming : bool
         Set to stem.
@@ -56,23 +69,47 @@ def get_lucene_analyzer(name='english', stemming=True, stemmer='porter', stopwor
     JAnalyzer
         Java ``Analyzer`` with specified settings.
     """
-    if name.lower() == 'arabic':
+    if language.lower() == 'ar':
         return JArabicAnalyzer()
-    elif name.lower() == 'bengali':
+    elif language.lower() == 'bn':
         return JBengaliAnalyzer()
-    elif name.lower() == 'cjk':
+    elif language.lower() in ['zh', 'ko']:
         return JCJKAnalyzer()
-    elif name.lower() == 'german':
-        return JGermanAnalyzer()
-    elif name.lower() == 'spanish':
-        return JSpanishAnalyzer()
-    elif name.lower() == 'french':
+    elif language.lower() == 'da':
+        return JDanishAnalyzer()
+    elif language.lower() == 'nl':
+        return JDutchAnalyzer()
+    elif language.lower() == 'fi':
+        return JFinnishAnalyzer()
+    elif language.lower() == 'fr':
         return JFrenchAnalyzer()
-    elif name.lower() == 'hindi':
+    elif language.lower() == 'de':
+        return JGermanAnalyzer()
+    elif language.lower() == 'hi':
         return JHindiAnalyzer()
-    elif name.lower() == 'tweet':
+    elif language.lower() == 'hu':
+        return JHungarianAnalyzer()
+    elif language.lower() == 'id':
+        return JIndonesianAnalyzer()
+    elif language.lower() == 'it':
+        return JItalianAnalyzer()
+    elif language.lower() == 'ja':
+        return JJapaneseAnalyzer()
+    elif language.lower() == 'no':
+        return JNorwegianAnalyzer()
+    elif language.lower() == 'pt':
+        return JPortugueseAnalyzer()
+    elif language.lower() == 'ru':
+        return JRussianAnalyzer()
+    elif language.lower() == 'es':
+        return JSpanishAnalyzer()
+    elif language.lower() == 'th':
+        return JThaiAnalyzer()
+    elif language.lower() == 'tr':
+        return JTurkishAnalyzer()
+    elif language.lower() == 'tweet':
         return JTweetAnalyzer()
-    elif name.lower() == 'english':
+    elif language.lower() == 'en':
         if stemming:
             if stopwords:
                 return JDefaultEnglishAnalyzer.newStemmingInstance(JString(stemmer))
